# Config Input Parameters Descriptions


| **Config Input Parameter**               | **Description**                                                                                                                                                                   | **Data Type(s) Accepted** |
|------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------|
| analysis_id                              | Index for managing T3CO analyses or runs                                                                                                                                       | int                   |
| analysis_name                            | Name of T3CO Analysis for user's reference                                                                                                                                     | string                |
| vehicle_file                             | Filepath to vehicle file relative to /t3co/ folder                                                                                                                             | string                |
| scenario_file                            | Filepath to scenario file relative to /t3co/ folder                                                                                                                            | string                |
| dst_dir                                  | Filepath to results destination directory                                                                                                                                      | string                |
| write_tsv                                | Boolean switch to save intermediate results files                                                                                                                              | bool                  |
| selections                               | List of selections from vehicle/scenario files to include in the analysis. Takes input as an integer or list of integers. '-1' makes T3CO run all vehicles in the vehicle file | int/list\[int\]              |
| vehicle_life_yr                          | Override number of TCO years for all selections.. If left blank, T3CO uses selection specific vehicle_life_yr from scenario file                                               | int                   |
| ess_max_charging_power_kw                | Override ESS max charging power for all selections. If left blank, T3CO uses selection specific ess_max_charging_power_kw from scenario file                                   | float                 |
| fs_fueling_rate_kg_per_min               | Override gaseous fueling fill rate for all selections. If left blank, T3CO uses selection specific fs_fueling_rate_kg_per_min from scenario file                               | float                 |
| fs_fueling_rate_gasoline_gpm             | Override gasoline liquid fueling fill rate for all selections. If left blank, T3CO uses selection specific fs_fueling_rate_gasoline_gpm from scenario file                     | float                 |
| fs_fueling_rate_diesel_gpm               | Override diesel liquid fueling fill rate for all selections. If left blank, T3CO uses selection specific fs_fueling_rate_diesel_gpm from scenario file                         | float                 |
| algorithms                               | Algorithm for pymoo optimization. Select from  ["NSGA2", "PatternSearch"]                                                                                                      | string                |
| lw_imp_curves                            | Filepath to lightweighting improvement cost curve relative to /t3co/ folder                                                                                                    | string                |
| eng_eff_imp_curves                       | Filepath to engine efficiency improvement cost curve relative to /t3co/ folder                                                                                                 | string                |
| aero_drag_imp_curves                     | Filepath to aerodynamic drag coefficient improvement cost curve relative to /t3co/ folder                                                                                      | string                |
| lw_imp_curve_sel                         | Override selection of light weighting improvement curve from lw_imp_curves file for all selections                                                                             | string                |
| eng_eff_imp_curve_sel                    | Override selection of engine efficiency improvement curve from eng_eff_imp_curves file for all selections                                                                      | string                |
| aero_drag_imp_curve_sel                  | Override selection of aerodynamic drag improvement curve from aero_drag_imp_curves file for all selections                                                                     | string                |
| skip_all_opt                             | Boolean switch to override skip optimization for all selections                                                                                                                | bool                  |
| constraint_range                         | Override boolean switch for optimization range constraint for all selections - if left blank, T3CO uses selection specific switch                                              | bool                  |
| constraint_accel                         | Override boolean switch for optimization acceleration constraint for all selections- if left blank, T3CO uses selection specific switch                                        | bool                  |
| constraint_grade                         | Override boolean switch for optimization gradeability constraint for all selections- if left blank, T3CO uses selection specific switch                                        | bool                  |
| objective_tco                            | Override boolean switch for optimization objective as TCO for all selections- if left blank, T3CO uses selection specific switch                                               | bool                  |
| constraint_c_rate                        | Override boolean switch for optimization charge rate constraint for all selections- if left blank, T3CO uses selection specific switch                                         | bool                  |
| constraint_trace_miss_dist_percent_on    | Override boolean switch for optimization distance trace miss percentage for all selections- if left blank, T3CO uses selection specific switch                                 | bool                  |
| objective_phev_minimize_fuel_use         | Override boolean switch for optimization objective for PHEV to minimize fuel consumption for all selections- if left blank, T3CO uses selection specific switch                | bool                  |
| activate_tco_payload_cap_cost_multiplier | Override boolean switch for lost payload capacity opportunity cost calculations- if left blank, T3CO uses selection specific switch                                            | bool                  |
| activate_tco_fueling_dwell_time_cost     | Override boolean switch for fueling dwell time opportunity cost calculations- if left blank, T3CO uses selection specific switch                                               | bool                  |
| fdt_frac_full_charge_bounds              | Override fraction of lower and upper bounds for fractional charge- if left blank, T3CO uses selection specific switch                                                          | list                  |
| activate_mr_downtime_cost                | Override boolean switch for maintenance and repair downtime opportunity cost calculations- if left blank, T3CO uses selection specific switch                                  | bool                  |
